/*
 * Software License Agreement (BSD License)
 *
 * Copyright (c) 2010, Kyoto University and Honda Motor Co.,Ltd. All rights reserved.
 *
 * HARK was developed by researchers in Okuno Laboratory at the Kyoto University and 
 * Honda Research Institute Japan Co.,Ltd.
 *
 * Redistribution and use in source and binary forms, with or without modification, are 
 * permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this list 
 *    of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, this 
 *    list of conditions and the following disclaimer in the documentation and/or other 
 *    materials provided with the distribution.
 *  * Neither the name of Kyoto University and Honda Motor Co.,Ltd., Inc. nor the names 
 *    of its contributors may be used to endorse or promote products derived from this 
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
 * SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCI-
 * DENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSI-
 * NESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTR-
 * ACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "BufferedNode.h"
#include "operators.h"
#include "CvfdContours.h"

using namespace std;
using namespace FD;

class CvfdFirstContour;
   
DECLARE_NODE(CvfdFirstContour)
/*Node
 *
 * @name CvfdFirstContour
 * @category FDOPENCV_ORG:Contours
 * @description Point to the first contour
 *
 * @input_name CONTOURSIN
 * @input_description The contour to handle
 * @input_type CvfdContours
 *
 * @output_name CONTOURSOUT
 * @output_description The result contour
 * @output_type CvfdContours
 *
 END*/
   
class CvfdFirstContour : public BufferedNode {
      
  //Input ID
  int m_contoursInID;

  //Output ID
  int m_contoursOutID;
  int m_nbElementsID;
      
      
public:
  CvfdFirstContour(string nodeName, ParameterSet params)
    : BufferedNode(nodeName, params)
  {
    //add inputs
    m_contoursInID = addInput("CONTOURSIN");
         
    //add outputs
    m_contoursOutID = addOutput("CONTOURSOUT");
         
  }
      
  void calculate(int output_id, int count, Buffer &out)
  {           
    //Read the inputs
    RCPtr<CvfdContours> contoursPtr = getInput(m_contoursInID,count);
    //Handle of the inputs
    if((contoursPtr->getContours()) == 0)
      {
	throw new GeneralException("OPENCV - Contour doesn't exist",__FILE__,__LINE__);
      } 
    CvfdContours* contours = new  CvfdContours(&(*contoursPtr));         
    contours->setContours(contours->getFirstContours());         
    out[count] = ObjectRef(contours); 

         
  }
      
  NO_ORDER_NODE_SPEEDUP(CvfdFirstContour)
};
